@@ -124,61 +124,6 @@ void F77_SUB(hetmixord)(double * Y0,
 			double * rlindiv,
 			int * fix0);
 
-void F77_SUB(hetmixcontmult)(double * Y0, 
-			     double * X0, 
-			     int * Prior0, 
-			     int * idprob0,
-			     int * idea0,
-			     int * idg0,
-			     int * idcor0,
-			     int * idcontr0,
-			     int * ny0,
-			     int * ns0,
-			     int * ng0,
-			     int * nv0,
-			     int * nobs0,
-			     int * nea0,
-			     int * nmes0,
-			     int * idiag0,
-			     int * nwg0,
-			     int * ncor0,
-			     int * nalea0,
-			     int * npmtot0,
-			     double * btot,
-			     double * Vopt,
-			     double * vrais,
-			     int * ni,
-			     int * istop,
-			     double * gconv,
-			     double * ppi0,
-			     double * resid_m,
-			     double * resid_ss,
-			     double * pred_m_g,
-			     double * pred_ss_g,
-			     double * pred_RE,
-			     double * pred_RE_Y,
-			     double * convB,
-			     double * convL,
-			     double * convG,
-			     int * maxiter0,
-			     double * epsY0,
-			     int * idlink0,
-			     int * nbzitr0,
-			     double * zitr0,
-			     double * uniqueY0,
-			     int * indiceY0,
-			     int * nvalspl0,
-			     double * marker,
-			     double * transfY,
-			     int * nsim0,
-			     double * Yobs,
-			     int * Ydiscret,
-			     double * vraisdiscret,
-			     double * UACV,
-			     double * rlindiv,
-			     int * pbH0,
-			     int * fix0);
-
 void F77_SUB(jointhet)(double * Y0, 
 		       double * X0, 
 		       int * Prior0,
@@ -531,7 +476,8 @@ void F77_SUB(hetmixmult)(double * Y0,
 			 int * methInteg0,
 			 int * nMC0,
 			 int * dimMC0,
-			 double * seqMC0);
+			 double * seqMC0,
+			 int * chol0);
 
 void F77_SUB(iteminfo)(double * X0,
 		       int * condRE_Y,
