@@ -2,7 +2,7 @@
 
 subroutine predictmult(X0,idprob,idea,idg,idcor,idcontr &
      ,ng,ncor,nalea,nv,ny,maxmes,idiag,nwg,npm,b1,epsY,idlink &
-     ,nbzitr,zitr0,nsim,methInteg,Ymarg)  
+     ,nbzitr,zitr0,modalite,nbmod,nsim,methInteg,Ymarg)  
 
   use optim
   IMPLICIT NONE
@@ -11,24 +11,26 @@ subroutine predictmult(X0,idprob,idea,idg,idcor,idcontr &
   integer,intent(in)::ng,ncor,nv,maxmes,idiag,nwg,npm,nsim,methInteg,nalea,ny
   double precision,dimension(maxmes*nv),intent(in) ::X0
   integer,dimension(nv),intent(in)::idprob,idea,idg,idcor,idcontr
-  integer,dimension(ny),intent(in)::idlink,nbzitr
+  integer,dimension(ny),intent(in)::idlink,nbzitr,nbmod
   double precision,dimension(npm),intent(in)::b1
   double precision,dimension(ny),intent(in) ::epsY
   double precision,dimension(maxval(nbzitr),ny),intent(in)::zitr0
+  integer, dimension(sum(nbmod)),intent(in)::modalite
 
   ! for computation
-  integer ::j,k,l,m,g,l2,m2,jj,npm2,j1,j2,yk,sumntrtot,q
+  integer ::j,k,l,m,g,l2,m2,jj,npm2,j1,j2,yk,sumntrtot,q,sumnbmod
   integer ::ier,nmoins,kk,nrisq,nvarxevt,niter,nvarprob,ncg,ncssg,nea,nef,nvc,nprob,ncontr
 !  double precision,dimension(nv) ::Xprob,  bprob
 !  double precision::temp
 !  double precision,dimension(ng) :: pi
   double precision,dimension(nv,nv) ::Ut,Ut1
 
-  double precision,dimension(:,:),allocatable::VC,Z,P,Corr,X00,X2,X01
-  double precision,dimension(:),allocatable::Vi,ysim,usim,mu,tcor
-  double precision,dimension(nv) :: b0,b2
+  double precision,dimension(:,:),allocatable::VC,Z,P,Corr,X00,X2,X01,Sigma
+  double precision,dimension(:),allocatable::Vi,ysim,usim,mu,tcor,usim2,asim,wsim
+  double precision,dimension(maxmes*ny)::wi
+  double precision,dimension(nv) :: b0,b2,uu
   double precision,dimension(nv*ny) :: b01 
-  double precision :: eps,ytemp2,x22
+  double precision :: eps,ytemp2,x22,ai
   double precision ::ytemp,diff,SX,beta
   double precision::aa1,bb1,dd1,aa,bb,cc1
   double precision,dimension(:),allocatable::zitr,splaa
@@ -36,6 +38,7 @@ subroutine predictmult(X0,idprob,idea,idg,idcor,idcontr &
   double precision,dimension(2,51)::gauss
   double precision,dimension(ny)::minY,maxY
   integer,dimension(ny)::ntrtot
+  double precision::alnorm
 
   ! for output
   double precision,dimension(maxmes*ny,ng),intent(out) ::Ymarg
@@ -46,7 +49,8 @@ subroutine predictmult(X0,idprob,idea,idg,idcor,idcontr &
 
   allocate(ysim(maxmes*ny),usim(maxmes*ny),mu(maxmes*ny),tcor(maxmes),Vi(maxmes*ny*(maxmes*ny+1)/2), &
        VC(maxmes*ny,maxmes*ny),Z(maxmes*ny,nv),P(maxmes*ny,nv),Corr(maxmes*ny,maxmes*ny), &
-       X00(maxmes*ny,nv),X2(maxmes*ny,nv),X01(maxmes*ny,nv*ny))
+       X00(maxmes*ny,nv),X2(maxmes*ny,nv),X01(maxmes*ny,nv*ny), usim2(nv), Sigma(maxmes,maxmes), &
+       asim(ny), wsim(maxmes*ny))
 
 !       print*,"apres allocate1"
   ! en prevision de l'extension au conjoint
@@ -64,6 +68,7 @@ subroutine predictmult(X0,idprob,idea,idg,idcor,idcontr &
   if (idlink(yk).eq.0) ntrtot(yk)=2
   if (idlink(yk).eq.1) ntrtot(yk)=4
   if (idlink(yk).eq.2) ntrtot(yk)=nbzitr(yk)+2
+  if (idlink(yk).eq.3) ntrtot(yk)=nbmod(yk)-1
   end do
   
 !  if(verbose==1) print*,"ntrtot=",ntrtot
@@ -227,58 +232,105 @@ subroutine predictmult(X0,idprob,idea,idg,idcor,idcontr &
                   Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2) = b1(nef+nvc+nwg+ncor)*b1(nef+nvc+nwg+ncor)*&
                   exp(-b1(nef+nvc+nwg+1)*abs(tcor(j1)-tcor(j2)))
                end if
-               
-               if(nalea.eq.ny) Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2) = Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2) +&
-               b1(nef+nvc+nwg+ncor+ny+yk)**2 !variance de alpha_k
-              
-               if(j1.eq.j2) Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2) = Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2)+&
-               b1(nef+nvc+nwg+ncor+yk) **2 ! variance de l'erreur
 
+               if(all(idlink.ne.3)) then
+                  if(nalea.eq.ny) Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2) = Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2) +&
+                       b1(nef+nvc+nwg+ncor+ny+yk)**2 !variance de alpha_k
+                  
+                  if(j1.eq.j2) Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2) = Corr(maxmes*(yk-1)+j1,maxmes*(yk-1)+j2)+&
+                       b1(nef+nvc+nwg+ncor+yk) **2 ! variance de l'erreur
+               end if
             end do
-         end do   
-        end do   
+         end do
+      end do
 
 
 !      print*,"Corr ok"
 
-! creation de P=Zi*Ut et V=P*P' que si non spec aux classes
+        ! creation de P=Zi*Ut et V=P*P' que si non spec aux classes
+           
 
-  if (nwg.eq.0.OR.NG.EQ.1) then
-     P=0.d0
-     P=MATMUL(Z,Ut)
-     VC=0.d0
-     VC=MATMUL(P,transpose(P))+Corr
-!       print*,"VC ok"
-     ! Vi en vecteur
+      if(all(idlink.ne.3)) then
+         
+         if (nwg.eq.0.OR.NG.EQ.1) then
+            P=0.d0
+            P=MATMUL(Z,Ut)
+            VC=0.d0
+            VC=MATMUL(P,transpose(P))+Corr
+            !       print*,"VC ok"
+            ! Vi en vecteur
+            
+            jj=0
+            Vi=0.d0
+            do j=1,maxmes*ny
+               do k=j,maxmes*ny
+                  jj=j+k*(k-1)/2
+                  Vi(jj)=VC(j,k)
+               end do
+            end do
+            
+            if (methInteg.eq.1) then 
+               CALL DMFSD(Vi,maxmes*ny,EPS,IER)
+               if (ier.eq.-1) then
+                  ymarg=9999.d0
+                  !           if (verbose==1) print*,"pb cholesky"
+                  goto 654
+               end if
+               
+               VC=0.d0
+               do j=1,maxmes*ny
+                  do k=1,j
+                     VC(j,k)=Vi(k+j*(j-1)/2)
+                  end do
+               end do
+            end if
+         end if
 
-     jj=0
-     Vi=0.d0
-     do j=1,maxmes*ny
-        do k=j,maxmes*ny
-           jj=j+k*(k-1)/2
-           Vi(jj)=VC(j,k)
-        end do
-     end do
+      else
 
-     if (methInteg.eq.1) then 
-        CALL DMFSD(Vi,maxmes*ny,EPS,IER)
-        if (ier.eq.-1) then
-           ymarg=9999.d0
-!           if (verbose==1) print*,"pb cholesky"
-           goto 654
-        end if
-        
-        VC=0.d0
-        do j=1,maxmes*ny
-           do k=1,j
-              VC(j,k)=Vi(k+j*(j-1)/2)
-           end do
-        end do
-     end if
-  end if
-     
+         if(any(idlink.eq.3)) then
 
-  ! contribution individuelle a la vraisemblance
+            VC=0.d0
+            do yk=1,ny
+               
+               Sigma=0.d0
+               do j1=1,maxmes
+                  do j2=1,maxmes 
+                     if(nalea.eq.ny) Sigma(j1,j2) = b1(nef+nvc+nwg+ncor+ny+yk)**2 !variance de alpha_k
+                     
+                     if(j1.eq.j2) Sigma(j1,j2) = Sigma(j1,j2)+&
+                          b1(nef+nvc+nwg+ncor+yk) **2 ! variance de l'erreur
+                  end do
+               end do
+               
+               jj=0
+               Vi=0.d0
+               do j=1,maxmes
+                  do k=j,maxmes
+                     jj=j+k*(k-1)/2
+                     Vi(jj)=Sigma(j,k)
+                  end do
+               end do
+               
+               CALL DMFSD(Vi,maxmes,EPS,IER)
+               if (ier.eq.-1) then
+                  ymarg=9999.d0
+                  goto 654
+               end if
+               
+               VC=0.d0
+               do j=1,maxmes
+                  do k=1,j
+                     VC((yk-1)*maxmes+j,(yk-1)*maxmes+k)=Vi(k+j*(j-1)/2)
+                  end do
+               end do
+               
+            end do
+            
+         end if
+         
+      end if
+      
 
   ! cas 1 : ng=1
 
@@ -330,108 +382,217 @@ subroutine predictmult(X0,idprob,idea,idg,idcor,idcontr &
 !        print*,"mu ok"
 !    if (verbose==1) print*,"mu=",mu
     
-    if(methInteg.eq.1) then !MC
-!         print*,"debut MC"
-      do l=1,nsim
-         
-         if(any(idlink.ne.0)) then
+     if(methInteg.eq.1) then !MC
+        !         print*,"debut MC"
+        do l=1,nsim
+           
+           if(any(idlink.ne.0)) then
+              
+              if(any(idlink.eq.3)) then
+
+                 !! simuler les effets aleatoires
+                 usim2=0.d0
+                 ysim=0.d0
+                 do m=1,nea
+                    SX=1.d0
+                    call bgos(SX,0,usim2(m),x22,0.d0)
+                 end do
+                 uu = 0.d0
+                 uu = matmul(Ut,usim2)
+                 ysim=matmul(X00,b0)+matmul(X01,b01)+matmul(Z,uu)
+
+                 !! simuler le BM ou AR
+                 if(ncor.gt.0) then
+                    wsim=0.d0
+                    x22=0.d0
+                    SX=1.d0
+                    do j=1,maxmes*ny
+                       call bgos(SX,0,wsim(j),x22,0.d0)
+                    end do
+                    wi=0.d0
+                    wi=matmul(Corr,wsim)
+                    ysim = ysim + wi
+                 end if
+                 
+            else
+               
               usim=0.d0
               ysim=0.d0
               do m=1,maxmes*ny
                  SX=1.d0
                  call bgos(SX,0,usim(m),x22,0.d0)
               end do
-             ysim=mu+MATMUL(VC,usim)
+              ysim=mu+MATMUL(VC,usim)
+
+           end if
           end if
 
-    sumntrtot=0
-    do yk=1,ny
-!          print*,"boucle sur idlink, yk=",yk, "nsim=",l
-     if (idlink(yk).eq.0 .and. l.eq.1) then  ! Linear link
-     
-         aa = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
-         bb = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)
-         do j=1,maxmes
-           Ymarg(maxmes*(yk-1)+j,1) = mu(maxmes*(yk-1)+j)*bb+aa
-         end do
-         
-         !sumntrtot = sumntrtot +ntrtot(yk) 
-         
-     else if (idlink(yk).eq.1) then  ! Beta link
+          sumntrtot=0
+          sumnbmod = 0
+          do yk=1,ny
+             
+             !          print*,"boucle sur idlink, yk=",yk, "nsim=",l
+             if (idlink(yk).eq.0 .and. l.eq.1) then  ! Linear link
+                
+                aa = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
+                bb = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)
+                do j=1,maxmes
+                   Ymarg(maxmes*(yk-1)+j,1) = mu(maxmes*(yk-1)+j)*bb+aa
+                end do
+                
+                !sumntrtot = sumntrtot +ntrtot(yk) 
+                
+             else if (idlink(yk).eq.3) then
 
-        aa1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1))/ &
-             (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)))
-        bb1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2))/ &
-             (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)))
-        bb1=aa1*(1.d0-aa1)*bb1
-
-        cc1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+3))
-
-        dd1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+4))
-
-        aa=aa1*aa1*(1-aa1)/bb1-aa1
-        bb=aa*(1-aa1)/aa1
-        beta=beta_ln(aa,bb)
-
-
-              do j=1,maxmes
-                 ytemp=ysim(maxmes*(yk-1)+j)*dd1+cc1
-                 if (ytemp.lt.0) then
-                    ytemp=0.d0
+                 !! simuler l'EA specifique au test
+                 ai=0.d0
+                 if(nalea.gt.0) then
+                    call bgos(SX,0,asim(yk),x22,0.d0)
+                    ai = b1(nprob+nef+ncontr+nvc+nwg+ncor+ny+yk)*asim(yk)
                  end if
+                 
+                aa = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
+                do j=1,maxmes
+                   if(nalea.gt.0) ysim((yk-1)*maxmes+j) = ysim((yk-1)*maxmes+j)+ai
+                   ytemp = modalite(sumnbmod + nbmod(yk)) - &
+                        alnorm((aa-ysim((yk-1)*maxmes+j))/abs(b1(nef+nvc+nwg+ncor+yk)),.false.)
+                   Ymarg(maxmes*(yk-1)+j,1) = Ymarg(maxmes*(yk-1)+j,1) + ytemp / dble(nsim)
+                end do
+
+                if(nbmod(yk).gt.2) then
+                   do jj=2,nbmod(yk)-1
+                      aa = aa + b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+jj)**2
+                      do j=1,maxmes
+                         ytemp = (modalite(sumnbmod + jj) - modalite(sumnbmod + jj+1))* &
+                              alnorm((aa-ysim((yk-1)*maxmes+j))/abs(b1(nef+nvc+nwg+ncor+yk)),.false.)
+                         Ymarg(maxmes*(yk-1)+j,1) = Ymarg(maxmes*(yk-1)+j,1) + ytemp / dble(nsim)                             
+                      end do
+                   end do
+                end if
+                
+                sumnbmod = sumnbmod + nbmod(yk)
+                
+             else if (idlink(yk).eq.1) then  ! Beta link
+                
+                aa1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1))/ &
+                     (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)))
+                bb1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2))/ &
+                     (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)))
+                bb1=aa1*(1.d0-aa1)*bb1
+                
+                cc1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+3))
+                
+                dd1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+4))
+                
+                aa=aa1*aa1*(1-aa1)/bb1-aa1
+                bb=aa*(1-aa1)/aa1
+                beta=beta_ln(aa,bb)
+
+                !! simuler une N(0,Sigma)
+                if(any(idlink.eq.3)) then
+                   usim=0.d0
+                   do m=1,maxmes
+                      SX=1.d0
+                      call bgos(SX,0,usim(m),x22,0.d0)
+                   end do
+
+                   Sigma=0.d0
+                   do j1=1,maxmes
+                      do j2=1,j1
+                         Sigma(j1,j2) = VC((yk-1)*maxmes+j1,(yk-1)*maxmes+j2)
+                      end do
+                   end do
+
+                   Vi=0.d0
+                   Vi = matmul(Sigma,usim)
+                   
+                   do j=1,maxmes
+                      ysim(maxmes*(yk-1)+j) = ysim(maxmes*(yk-1)+j) + Vi(j)
+                   end do
+                end if
+                   
+                
+                do j=1,maxmes
+                   ytemp=ysim(maxmes*(yk-1)+j)*dd1+cc1
+                   if (ytemp.lt.0) then
+                      ytemp=0.d0
+                   end if
                  if (ytemp.gt.1) then
                     ytemp=1.d0
                  end if
                  ymarg(maxmes*(yk-1)+j,1)=ymarg(maxmes*(yk-1)+j,1)+xinbta(aa,bb,beta,ytemp,ier)/dble(nsim)
                  if (ier.ne.0.or.ymarg(maxmes*(yk-1)+j,1).eq.9999.d0) then
                     ymarg(maxmes*(yk-1)+j,1)=9999.d0
-!                    if (verbose==1) print*,"pb beta"
+                    !                    if (verbose==1) print*,"pb beta"
                  end if
               end do
+              
+              !sumntrtot = sumntrtot +ntrtot(yk) 
+              
+           else if (idlink(yk).eq.2) then ! Splines link
+              
+              zitr=0.d0
+              zitr(1:nbzitr(yk))=zitr0(1:nbzitr(yk),yk)
+              zitr(-1)=zitr(1)
+              zitr(0)=zitr(1)
+              zitr(ntrtot(yk)-1)=zitr(ntrtot(yk)-2)
+              zitr(ntrtot(yk))=zitr(ntrtot(yk)-1)
+              
+              !       if(verbose==1 .and. l==1) print*,"yk=",yk,"zitr=",zitr
+              
+              bb=b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
+              do kk=2,ntrtot(yk)
+                 splaa(kk-3)=b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+kk)**2
+              end do
+              
+              !! simuler une N(0,Sigma)
+              if(any(idlink.eq.3)) then
+                 usim=0.d0
+                 do m=1,maxmes
+                    SX=1.d0
+                    call bgos(SX,0,usim(m),x22,0.d0)
+                 end do
+                   
+                 Sigma=0.d0
+                 do j1=1,maxmes
+                    do j2=1,j1
+                       Sigma(j1,j2) = VC((yk-1)*maxmes+j1,(yk-1)*maxmes+j2)
+                    end do
+                 end do
 
-         !sumntrtot = sumntrtot +ntrtot(yk) 
-         
-     else if (idlink(yk).eq.2) then ! Splines link
-     
-        zitr=0.d0
-        zitr(1:nbzitr(yk))=zitr0(1:nbzitr(yk),yk)
-        zitr(-1)=zitr(1)
-        zitr(0)=zitr(1)
-        zitr(ntrtot(yk)-1)=zitr(ntrtot(yk)-2)
-        zitr(ntrtot(yk))=zitr(ntrtot(yk)-1)
-
-!       if(verbose==1 .and. l==1) print*,"yk=",yk,"zitr=",zitr
-
-        bb=b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
-        do kk=2,ntrtot(yk)
-           splaa(kk-3)=b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+kk)**2
-        end do
-
+                 Vi=0.d0
+                 Vi = matmul(Sigma,usim)
+                 
+                 do j=1,maxmes
+                    ysim(maxmes*(yk-1)+j) = ysim(maxmes*(yk-1)+j) + Vi(j)
+                 end do
+              end if
+                 
               do j=1,maxmes
                  niter=0
                  diff=0.d0
                  ier=0
                  ytemp=INV_ISPLINES(ysim(maxmes*(yk-1)+j),splaa,bb,nbzitr(yk),zitr,ier,niter,diff)
-                    if ((ier.eq.3).or.(ier.ne.1.and.diff.gt.1.d-3).or.ymarg(maxmes*(yk-1)+j,1).eq.9999.d0) then
-                       ymarg(maxmes*(yk-1)+j,1)=9999.d0
-!                       if (verbose==1) print*,"pb inversion splines"
-                    else
-                        ymarg(maxmes*(yk-1)+j,1)=ymarg(maxmes*(yk-1)+j,1)+ytemp/dble(nsim)
-                    end if
-
+                 if ((ier.eq.3).or.(ier.ne.1.and.diff.gt.1.d-3).or.ymarg(maxmes*(yk-1)+j,1).eq.9999.d0) then
+                    ymarg(maxmes*(yk-1)+j,1)=9999.d0
+                    !                       if (verbose==1) print*,"pb inversion splines"
+                 else
+                    ymarg(maxmes*(yk-1)+j,1)=ymarg(maxmes*(yk-1)+j,1)+ytemp/dble(nsim)
+                 end if
+                 
               end do
               
-         !sumntrtot = sumntrtot+ntrtot(yk)     
-
-        end if
-        sumntrtot = sumntrtot+ntrtot(yk) 
+              !sumntrtot = sumntrtot+ntrtot(yk)     
+              
+           end if
+           sumntrtot = sumntrtot+ntrtot(yk) 
+        end do
      end do
- end do
- ! fin MC
-
+     ! fin MC
+     
   else !GH
-!      print*,"debut GH"
-    call gausshermite(gauss,nsim) ! on a les nsim poids et points d'integration dans gauss
+     !      print*,"debut GH"
+     call gausshermite(gauss,nsim) ! on a les nsim poids et points d'integration dans gauss
  
    sumntrtot=0
    do yk=1,ny
@@ -647,7 +808,7 @@ end if
 
         ! variance covariance si spec aux classes :
 
-        Ut1=Ut
+               Ut1=Ut
         if (nwg.ne.0) then
            Ut1=0.d0
            if (g.eq.ng) then
@@ -656,7 +817,7 @@ end if
               Ut1=Ut*abs(b1(nef+nvc+g))
            end if
 
-
+           if(all(idlink.ne.3)) then 
            P=0.d0
            P=MATMUL(Z,Ut1)
            VC=0.d0
@@ -688,6 +849,7 @@ end if
               end do
            end if
         end if
+     end if
 
         mu=0.d0
         mu=matmul(X00,b0)+matmul(X2,b2)+matmul(X01,b01)
@@ -700,43 +862,128 @@ end if
       do l=1,nsim
          
          if(any(idlink.ne.0)) then
-              usim=0.d0
-              ysim=0.d0
-              do m=1,maxmes*ny
-                 SX=1.d0
-                 call bgos(SX,0,usim(m),x22,0.d0)
-              end do
-             ysim=mu+MATMUL(VC,usim)
-          end if
+
+            if(any(idlink.eq.3)) then
+
+               !! simuler les effets aleatoires
+               usim2=0.d0
+               ysim=0.d0
+               do m=1,nea
+                  SX=1.d0
+                  call bgos(SX,0,usim2(m),x22,0.d0)
+               end do
+               uu = 0.d0
+               uu = matmul(Ut1,usim2)
+               ysim = mu+matmul(Z,uu)
+               
+               !! simuler le BM ou AR
+               if(ncor.gt.0) then
+                  wsim=0.d0
+                  x22=0.d0
+                  SX=1.d0
+                  do j=1,maxmes*ny
+                     call bgos(SX,0,wsim(j),x22,0.d0)
+                  end do
+                  wi=0.d0
+                  wi=matmul(Corr,wsim)
+                  ysim = ysim + wi
+               end if
+
+            else
+               
+               usim=0.d0
+               ysim=0.d0
+               do m=1,maxmes*ny
+                  SX=1.d0
+                  call bgos(SX,0,usim(m),x22,0.d0)
+               end do
+               ysim=mu+MATMUL(VC,usim)
+               
+            end if
+         end if
 
 !    if (verbose==1) print*,"ysim=",ysim
       sumntrtot=0
+      sumnbmod = 0
       do yk=1,ny
 !          print*,"boucle idlink, yk et nsim=",yk,nsim 
-        if (idlink(yk).eq.0 .and. l.eq.1) then  ! Linear link
-         aa = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
-         bb = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)
-         do j=1,maxmes
-           Ymarg(maxmes*(yk-1)+j,g) = mu(maxmes*(yk-1)+j)*bb+aa
-         end do
-         sumntrtot = sumntrtot +ntrtot(yk)          
+         if (idlink(yk).eq.0 .and. l.eq.1) then  ! Linear link
+            
+            aa = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
+            bb = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)
+            do j=1,maxmes
+               Ymarg(maxmes*(yk-1)+j,g) = mu(maxmes*(yk-1)+j)*bb+aa
+            end do     
+            
+         else if (idlink(yk).eq.3) then ! ordinal
 
+           !! simuler l'EA specifique au test
+           ai=0.d0
+           if(nalea.gt.0) then
+              call bgos(SX,0,asim(yk),x22,0.d0)
+              ai = b1(nprob+nef+ncontr+nvc+nwg+ncor+ny+yk)*asim(yk)
+           end if
+           
+           aa = b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)
+           do j=1,maxmes
+              if(nalea.gt.0) ysim((yk-1)*maxmes+j) = ysim((yk-1)*maxmes+j)+ai
+              ytemp = modalite(sumnbmod + nbmod(yk)) - &
+                   alnorm((aa-ysim((yk-1)*maxmes+j))/abs(b1(nef+nvc+nwg+ncor+yk)),.false.)
+              Ymarg(maxmes*(yk-1)+j,g) = Ymarg(maxmes*(yk-1)+j,g) + ytemp / dble(nsim)
+           end do
+           
+           if(nbmod(yk).gt.2) then
+              do jj=2,nbmod(yk)-1
+                 aa = aa + b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+jj)**2
+                 do j=1,maxmes
+                    ytemp = (modalite(sumnbmod + jj) - modalite(sumnbmod + jj+1))* &
+                         alnorm((aa-ysim((yk-1)*maxmes+j))/abs(b1(nef+nvc+nwg+ncor+yk)),.false.)
+                    Ymarg(maxmes*(yk-1)+j,g) = Ymarg(maxmes*(yk-1)+j,g) + ytemp / dble(nsim)                             
+                 end do
+              end do
+           end if
+           
+           sumnbmod = sumnbmod + nbmod(yk)
+                
         else if (idlink(yk).eq.1) then  ! Beta link
-        aa1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1))/ &
-             (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)))
-        bb1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2))/ &
-             (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)))
-        bb1=aa1*(1.d0-aa1)*bb1
-
-        cc1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+3))
-
-        dd1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+4))
-
-        aa=aa1*aa1*(1-aa1)/bb1-aa1
-        bb=aa*(1-aa1)/aa1
-        beta=beta_ln(aa,bb)
-
-
+              
+           aa1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1))/ &
+                   (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+1)))
+              bb1=exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2))/ &
+                   (1+exp(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+2)))
+              bb1=aa1*(1.d0-aa1)*bb1
+              
+              cc1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+3))
+              
+              dd1=abs(b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+4))
+              
+              aa=aa1*aa1*(1-aa1)/bb1-aa1
+              bb=aa*(1-aa1)/aa1
+              beta=beta_ln(aa,bb)
+              
+              !! simuler une N(0,Sigma)
+              if(any(idlink.eq.3)) then
+                 usim=0.d0
+                 do m=1,maxmes
+                    SX=1.d0
+                    call bgos(SX,0,usim(m),x22,0.d0)
+                 end do
+                 
+                 Sigma=0.d0
+                 do j1=1,maxmes
+                    do j2=1,j1
+                       Sigma(j1,j2) = VC((yk-1)*maxmes+j1,(yk-1)*maxmes+j2)
+                    end do
+                 end do
+                 
+                 Vi=0.d0
+                 Vi = matmul(Sigma,usim)
+                 
+                 do j=1,maxmes
+                    ysim(maxmes*(yk-1)+j) = ysim(maxmes*(yk-1)+j) + Vi(j)
+                 end do
+              end if
+              
               do j=1,maxmes
                  ytemp=ysim(maxmes*(yk-1)+j)*dd1+cc1
                  if (ytemp.lt.0) then
@@ -752,9 +999,8 @@ end if
                  end if
               end do
 
-         sumntrtot = sumntrtot +ntrtot(yk) 
-
-        else if (idlink(yk).eq.2) then ! Splines link
+      else if (idlink(yk).eq.2) then ! Splines link
+         
         zitr=0.d0
         zitr(1:nbzitr(yk))=zitr0(1:nbzitr(yk),yk)
         zitr(-1)=zitr(1)
@@ -766,28 +1012,51 @@ end if
         do kk=2,ntrtot(yk)
            splaa(kk-3)=b1(nef+nvc+nwg+ncor+ny+nalea+sumntrtot+kk)**2
         end do
-
-              do j=1,maxmes
-                 niter=0
-                 diff=0.d0
-                 ier=0
-                 ytemp=INV_ISPLINES(ysim(maxmes*(yk-1)+j),splaa,bb,nbzitr(yk),zitr,ier,niter,diff)
-                    if ((ier.eq.3).or.(ier.ne.1 .and. diff.gt.1.d-3).or.ymarg(maxmes*(yk-1)+j,g).eq.9999.d0) then
-                       ymarg(maxmes*(yk-1)+j,g)=9999.d0
-!                       if (verbose==1) print*,"pb splines"
-                    else
-                        ymarg(maxmes*(yk-1)+j,g)=ymarg(maxmes*(yk-1)+j,g)+ytemp/dble(nsim)
-                    end if
-
+  
+        !! simuler une N(0,Sigma)
+        if(any(idlink.eq.3)) then
+           usim=0.d0
+           do m=1,maxmes
+              SX=1.d0
+              call bgos(SX,0,usim(m),x22,0.d0)
+           end do
+           
+           Sigma=0.d0
+           do j1=1,maxmes
+              do j2=1,j1
+                 Sigma(j1,j2) = VC((yk-1)*maxmes+j1,(yk-1)*maxmes+j2)
               end do
-              
-         sumntrtot = sumntrtot+ntrtot(yk)     
-
-  end if
+           end do
+           
+           Vi=0.d0
+           Vi = matmul(Sigma,usim)
+           
+           do j=1,maxmes
+              ysim(maxmes*(yk-1)+j) = ysim(maxmes*(yk-1)+j) + Vi(j)
+           end do
+        end if
+        
+        do j=1,maxmes
+           niter=0
+           diff=0.d0
+           ier=0
+           ytemp=INV_ISPLINES(ysim(maxmes*(yk-1)+j),splaa,bb,nbzitr(yk),zitr,ier,niter,diff)
+           if ((ier.eq.3).or.(ier.ne.1 .and. diff.gt.1.d-3).or.ymarg(maxmes*(yk-1)+j,g).eq.9999.d0) then
+              ymarg(maxmes*(yk-1)+j,g)=9999.d0
+              !                       if (verbose==1) print*,"pb splines"
+           else
+              ymarg(maxmes*(yk-1)+j,g)=ymarg(maxmes*(yk-1)+j,g)+ytemp/dble(nsim)
+           end if
+           
+        end do
+        
+     end if
   ! fin if idlink
+        
+     sumntrtot = sumntrtot+ntrtot(yk)     
   
   end do
-  end do
+end do
   
   else !GH
 !       print*,"debut GH"
@@ -914,7 +1183,7 @@ end do
 654 continue
 !        print*,"avant delocate"
   deallocate(zitr,splaa)
-  deallocate(Z,P,Corr,X00,X2,X01,ysim,usim,mu,tcor,VC,Vi)
+  deallocate(Z,P,Corr,X00,X2,X01,ysim,usim,mu,tcor,VC,Vi,usim2,Sigma,wsim,asim)
 
 
   return
